<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>De vliegtuigstand is ingeschakeld</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>De vliegtuigstand is uitgeschakeld</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Uitschakelen</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Vliegtuigstand</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Vliegtuigstandinstellingen</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Vliegtuigstand</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Mijn apparaten</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetoothinstellingen</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation>Schakel de [vliegtuigstand](#) uit als je verbinding wilt maken via bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Uitschakelen</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetoothinstellingen</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>Verbonden met ‘%1’</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Bezig met verbinden…</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Verbonden met ‘%1’</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Uit</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Helderheid</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Beeldscherminstellingen</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Beeldscherminstellingen</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Helderheid</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>zo</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>ma</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>di</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>woe</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>do</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>vrij</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>za</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Toetsenbordindeling toevoegen</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum en tijd</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-uursklok</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-uursklok</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Tijdinstellingen</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Agenda openen</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Maandag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dinsdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Woensdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donderdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Vrijdag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Zaterdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Zondag</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>maandag</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>dinsdag</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>woensdag</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>donderdag</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>vrijdag</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>zaterdag</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>zondag</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Andere apparaten</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Niet-storenstand</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Niet-storenstandinstellingen</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Uitschakelen</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>De niet-storenstand is ingeschakeld</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>De niet-storenstand is uitgeschakeld</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Niet-storenstand</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Oogcomfort</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Oogcomfort is ingeschakeld</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Oogcomfort is uitgeschakeld</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Beeldscherminstellingen</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Oogcomfort</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Aan</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Uit</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Licht</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Donker</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Oogcomfort uitschakelen</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Oogcomfort inschakelen</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Beeldscherminstellingen</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Thema: licht</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Thema: donker</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Thema: automatisch</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Visuele effecten</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Licht</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Donker</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Geen berichten</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Meldingsinstellingen</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Meldingen</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Niet storen uitschakelen</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Niet storen inschakelen</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Melding</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Schermtoetsenbord</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Hoge prestaties</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Gebalanceerd</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Energiebesparing</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Gebalanceerde prestaties</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Energie-instellingen</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Accuniveau: %1 - %2 min resterend</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Accuniveau: %1 - %2 uur en %3 min resterend</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 opgeladen - klaar over %2 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 opgeladen - klaar over %2 uur en %3 min</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Accuniveau: %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Bezig met opladen %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Accuniveau: %1 …</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Accuniveau: %1 - volledig opgeladen</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Capaciteit: %1 - niet aan het opladen</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Accu</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Bezig met opladen en berekenen van resterende oplaadtijd…</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Bezig met berekenen van resterende gebruikstijd…</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 min. resterend</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 uur en %2 min. resterend</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Niet aan het opladen</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Volledig opgeladen</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Bezig met opladen - klaar over %1 min.</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Bezig met opladen - klaar over %1 uur en %2 min.</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Accuniveau: %1 - %2 uur resterend</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 uur resterend</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>%1 opgeladen - klaar over %2 uur</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Bezig met opladen - klaar over %1 uur</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Energie-instellingen</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Muziek</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Vergrendelen</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energie-instellingen</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Bijwerken en afsluiten</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Bijwerken en herstarten</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Andere gebruiker</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Vandaag</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Maan</translation>
    </message>
    <message>
        <source>y</source>
        <translation>j</translation>
    </message>
    <message>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <source>d</source>
        <translation>d</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Maandag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dinsdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Woensdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donderdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Vrijdag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Zaterdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Zondag</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>jan</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>feb</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>maa</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>apr</translation>
    </message>
    <message>
        <source>May</source>
        <translation>mei</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>jun</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>jul</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>aug</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>sep</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>okt</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>nov</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>dec</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Agenda openen</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>maandag</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>dinsdag</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>woensdag</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>donderdag</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>vrijdag</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>zaterdag</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>zondag</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Uitvoer</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Geluidsinstellingen</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Geluid</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Ontdempen</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Dempen</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Geluidsinstellingen</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Geen uitvoerapparaten</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>%1 volume</translation>
    </message>
</context>
</TS>